@@ -41,7 +41,9 @@ class ApiIntegration(
         api_key: typing.Optional[builtins.str] = None,
         azure_ad_application_id: typing.Optional[builtins.str] = None,
         azure_tenant_id: typing.Optional[builtins.str] = None,
+        comment: typing.Optional[builtins.str] = None,
         enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        google_audience: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
@@ -63,7 +65,9 @@ class ApiIntegration(
         :param api_key: The API key (also called a “subscription key”). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#api_key ApiIntegration#api_key}
         :param azure_ad_application_id: The 'Application (client) id' of the Azure AD app for your remote service. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#azure_ad_application_id ApiIntegration#azure_ad_application_id}
         :param azure_tenant_id: Specifies the ID for your Office 365 tenant that all Azure API Management instances belong to. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#azure_tenant_id ApiIntegration#azure_tenant_id}
+        :param comment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#comment ApiIntegration#comment}.
         :param enabled: Specifies whether this API integration is enabled or disabled. If the API integration is disabled, any external function that relies on it will not work. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#enabled ApiIntegration#enabled}
+        :param google_audience: The audience claim when generating the JWT (JSON Web Token) to authenticate to the Google API Gateway. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#google_audience ApiIntegration#google_audience}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#id ApiIntegration#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
         :param count: 
@@ -86,7 +90,9 @@ class ApiIntegration(
             api_key=api_key,
             azure_ad_application_id=azure_ad_application_id,
             azure_tenant_id=azure_tenant_id,
+            comment=comment,
             enabled=enabled,
+            google_audience=google_audience,
             id=id,
             connection=connection,
             count=count,
@@ -119,10 +125,18 @@ class ApiIntegration(
     def reset_azure_tenant_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetAzureTenantId", []))
 
+    @jsii.member(jsii_name="resetComment")
+    def reset_comment(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetComment", []))
+
     @jsii.member(jsii_name="resetEnabled")
     def reset_enabled(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetEnabled", []))
 
+    @jsii.member(jsii_name="resetGoogleAudience")
+    def reset_google_audience(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetGoogleAudience", []))
+
     @jsii.member(jsii_name="resetId")
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
@@ -196,6 +210,11 @@ class ApiIntegration(
     def azure_tenant_id_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "azureTenantIdInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="commentInput")
+    def comment_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "commentInput"))
+
     @builtins.property
     @jsii.member(jsii_name="enabledInput")
     def enabled_input(
@@ -203,6 +222,11 @@ class ApiIntegration(
     ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "enabledInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="googleAudienceInput")
+    def google_audience_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "googleAudienceInput"))
+
     @builtins.property
     @jsii.member(jsii_name="idInput")
     def id_input(self) -> typing.Optional[builtins.str]:
@@ -297,6 +321,18 @@ class ApiIntegration(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "azureTenantId", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="comment")
+    def comment(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "comment"))
+
+    @comment.setter
+    def comment(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__982190183217405c5c35d89d09c076fa18657a77a1e38380f931f485c361d01b)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "comment", value)
+
     @builtins.property
     @jsii.member(jsii_name="enabled")
     def enabled(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
@@ -312,6 +348,18 @@ class ApiIntegration(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enabled", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="googleAudience")
+    def google_audience(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "googleAudience"))
+
+    @google_audience.setter
+    def google_audience(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e34f7fd36f10f7d3a57072b3f21b687f5ec8ab9cbdc4538a31ba55668f199f70)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "googleAudience", value)
+
     @builtins.property
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
@@ -356,7 +404,9 @@ class ApiIntegration(
         "api_key": "apiKey",
         "azure_ad_application_id": "azureAdApplicationId",
         "azure_tenant_id": "azureTenantId",
+        "comment": "comment",
         "enabled": "enabled",
+        "google_audience": "googleAudience",
         "id": "id",
     },
 )
@@ -379,7 +429,9 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         api_key: typing.Optional[builtins.str] = None,
         azure_ad_application_id: typing.Optional[builtins.str] = None,
         azure_tenant_id: typing.Optional[builtins.str] = None,
+        comment: typing.Optional[builtins.str] = None,
         enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        google_audience: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -398,7 +450,9 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param api_key: The API key (also called a “subscription key”). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#api_key ApiIntegration#api_key}
         :param azure_ad_application_id: The 'Application (client) id' of the Azure AD app for your remote service. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#azure_ad_application_id ApiIntegration#azure_ad_application_id}
         :param azure_tenant_id: Specifies the ID for your Office 365 tenant that all Azure API Management instances belong to. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#azure_tenant_id ApiIntegration#azure_tenant_id}
+        :param comment: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#comment ApiIntegration#comment}.
         :param enabled: Specifies whether this API integration is enabled or disabled. If the API integration is disabled, any external function that relies on it will not work. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#enabled ApiIntegration#enabled}
+        :param google_audience: The audience claim when generating the JWT (JSON Web Token) to authenticate to the Google API Gateway. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#google_audience ApiIntegration#google_audience}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#id ApiIntegration#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
@@ -420,7 +474,9 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument api_key", value=api_key, expected_type=type_hints["api_key"])
             check_type(argname="argument azure_ad_application_id", value=azure_ad_application_id, expected_type=type_hints["azure_ad_application_id"])
             check_type(argname="argument azure_tenant_id", value=azure_tenant_id, expected_type=type_hints["azure_tenant_id"])
+            check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
+            check_type(argname="argument google_audience", value=google_audience, expected_type=type_hints["google_audience"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "api_allowed_prefixes": api_allowed_prefixes,
@@ -451,8 +507,12 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["azure_ad_application_id"] = azure_ad_application_id
         if azure_tenant_id is not None:
             self._values["azure_tenant_id"] = azure_tenant_id
+        if comment is not None:
+            self._values["comment"] = comment
         if enabled is not None:
             self._values["enabled"] = enabled
+        if google_audience is not None:
+            self._values["google_audience"] = google_audience
         if id is not None:
             self._values["id"] = id
 
@@ -595,6 +655,12 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("azure_tenant_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def comment(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#comment ApiIntegration#comment}.'''
+        result = self._values.get("comment")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def enabled(
         self,
@@ -608,6 +674,15 @@ class ApiIntegrationConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("enabled")
         return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
+    @builtins.property
+    def google_audience(self) -> typing.Optional[builtins.str]:
+        '''The audience claim when generating the JWT (JSON Web Token) to authenticate to the Google API Gateway.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#google_audience ApiIntegration#google_audience}
+        '''
+        result = self._values.get("google_audience")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/api_integration#id ApiIntegration#id}.
@@ -649,7 +724,9 @@ def _typecheckingstub__204eb5fba5f9443c11ac1c6e430df6b8c3ba4b4d846d99c1b4702b004
     api_key: typing.Optional[builtins.str] = None,
     azure_ad_application_id: typing.Optional[builtins.str] = None,
     azure_tenant_id: typing.Optional[builtins.str] = None,
+    comment: typing.Optional[builtins.str] = None,
     enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    google_audience: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
     count: typing.Optional[jsii.Number] = None,
@@ -704,12 +781,24 @@ def _typecheckingstub__65cb421ab5e94a46d1baccfe80f78ca3551f4ef88776b87eda483b9da
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__982190183217405c5c35d89d09c076fa18657a77a1e38380f931f485c361d01b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__59241600f54cec13075440cffd445a80e640dbcc0256c0cc958753cc196c0ba7(
     value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
 ) -> None:
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__e34f7fd36f10f7d3a57072b3f21b687f5ec8ab9cbdc4538a31ba55668f199f70(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__0bd97d10039590fd96a7ae8c8f4c4d679af7738b370560dfd0993a444aadb02d(
     value: builtins.str,
 ) -> None:
@@ -739,7 +828,9 @@ def _typecheckingstub__599fea4ee0fc1c0ff8b2a16fef2ca6f3f89d9400f965f49111252edb0
     api_key: typing.Optional[builtins.str] = None,
     azure_ad_application_id: typing.Optional[builtins.str] = None,
     azure_tenant_id: typing.Optional[builtins.str] = None,
+    comment: typing.Optional[builtins.str] = None,
     enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    google_audience: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
