@@ -34,10 +34,10 @@ class ObjectParameter(
         id_: builtins.str,
         *,
         key: builtins.str,
-        object_identifier: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["ObjectParameterObjectIdentifier", typing.Dict[builtins.str, typing.Any]]]],
-        object_type: builtins.str,
         value: builtins.str,
         id: typing.Optional[builtins.str] = None,
+        object_identifier: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["ObjectParameterObjectIdentifier", typing.Dict[builtins.str, typing.Any]]]]] = None,
+        object_type: typing.Optional[builtins.str] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
         depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
@@ -51,10 +51,10 @@ class ObjectParameter(
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param key: Name of object parameter. Valid values are those in `object parameters <https://docs.snowflake.com/en/sql-reference/parameters.html#object-parameters>`_. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#key ObjectParameter#key}
-        :param object_identifier: object_identifier block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
-        :param object_type: Type of object to which the parameter applies. Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
         :param value: Value of object parameter, as a string. Constraints are the same as those for the parameters in Snowflake documentation. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#value ObjectParameter#value}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#id ObjectParameter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param object_identifier: object_identifier block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
+        :param object_type: Type of object to which the parameter applies. Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_. If no value is provided, then the resource will default to setting the object parameter at account level. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -69,10 +69,10 @@ class ObjectParameter(
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ObjectParameterConfig(
             key=key,
-            object_identifier=object_identifier,
-            object_type=object_type,
             value=value,
             id=id,
+            object_identifier=object_identifier,
+            object_type=object_type,
             connection=connection,
             count=count,
             depends_on=depends_on,
@@ -101,6 +101,14 @@ class ObjectParameter(
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
 
+    @jsii.member(jsii_name="resetObjectIdentifier")
+    def reset_object_identifier(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetObjectIdentifier", []))
+
+    @jsii.member(jsii_name="resetObjectType")
+    def reset_object_type(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetObjectType", []))
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
@@ -203,10 +211,10 @@ class ObjectParameter(
         "provider": "provider",
         "provisioners": "provisioners",
         "key": "key",
-        "object_identifier": "objectIdentifier",
-        "object_type": "objectType",
         "value": "value",
         "id": "id",
+        "object_identifier": "objectIdentifier",
+        "object_type": "objectType",
     },
 )
 class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
@@ -221,10 +229,10 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         key: builtins.str,
-        object_identifier: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["ObjectParameterObjectIdentifier", typing.Dict[builtins.str, typing.Any]]]],
-        object_type: builtins.str,
         value: builtins.str,
         id: typing.Optional[builtins.str] = None,
+        object_identifier: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["ObjectParameterObjectIdentifier", typing.Dict[builtins.str, typing.Any]]]]] = None,
+        object_type: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param connection: 
@@ -235,10 +243,10 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param provider: 
         :param provisioners: 
         :param key: Name of object parameter. Valid values are those in `object parameters <https://docs.snowflake.com/en/sql-reference/parameters.html#object-parameters>`_. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#key ObjectParameter#key}
-        :param object_identifier: object_identifier block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
-        :param object_type: Type of object to which the parameter applies. Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
         :param value: Value of object parameter, as a string. Constraints are the same as those for the parameters in Snowflake documentation. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#value ObjectParameter#value}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#id ObjectParameter#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param object_identifier: object_identifier block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
+        :param object_type: Type of object to which the parameter applies. Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_. If no value is provided, then the resource will default to setting the object parameter at account level. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -252,14 +260,12 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
-            check_type(argname="argument object_identifier", value=object_identifier, expected_type=type_hints["object_identifier"])
-            check_type(argname="argument object_type", value=object_type, expected_type=type_hints["object_type"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument object_identifier", value=object_identifier, expected_type=type_hints["object_identifier"])
+            check_type(argname="argument object_type", value=object_type, expected_type=type_hints["object_type"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "key": key,
-            "object_identifier": object_identifier,
-            "object_type": object_type,
             "value": value,
         }
         if connection is not None:
@@ -278,6 +284,10 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["provisioners"] = provisioners
         if id is not None:
             self._values["id"] = id
+        if object_identifier is not None:
+            self._values["object_identifier"] = object_identifier
+        if object_type is not None:
+            self._values["object_type"] = object_type
 
     @builtins.property
     def connection(
@@ -351,28 +361,6 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         assert result is not None, "Required property 'key' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def object_identifier(
-        self,
-    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["ObjectParameterObjectIdentifier"]]:
-        '''object_identifier block.
-
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
-        '''
-        result = self._values.get("object_identifier")
-        assert result is not None, "Required property 'object_identifier' is missing"
-        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["ObjectParameterObjectIdentifier"]], result)
-
-    @builtins.property
-    def object_type(self) -> builtins.str:
-        '''Type of object to which the parameter applies. Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_.
-
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
-        '''
-        result = self._values.get("object_type")
-        assert result is not None, "Required property 'object_type' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def value(self) -> builtins.str:
         '''Value of object parameter, as a string. Constraints are the same as those for the parameters in Snowflake documentation.
@@ -393,6 +381,28 @@ class ObjectParameterConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def object_identifier(
+        self,
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["ObjectParameterObjectIdentifier"]]]:
+        '''object_identifier block.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_identifier ObjectParameter#object_identifier}
+        '''
+        result = self._values.get("object_identifier")
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["ObjectParameterObjectIdentifier"]]], result)
+
+    @builtins.property
+    def object_type(self) -> typing.Optional[builtins.str]:
+        '''Type of object to which the parameter applies.
+
+        Valid values are those in `object types <https://docs.snowflake.com/en/sql-reference/parameters.html#object-types>`_. If no value is provided, then the resource will default to setting the object parameter at account level.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/object_parameter#object_type ObjectParameter#object_type}
+        '''
+        result = self._values.get("object_type")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -687,10 +697,10 @@ def _typecheckingstub__4d49ddc05dbb3790c1054f88a7d363b4e505864054fa7449007f0acaf
     id_: builtins.str,
     *,
     key: builtins.str,
-    object_identifier: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ObjectParameterObjectIdentifier, typing.Dict[builtins.str, typing.Any]]]],
-    object_type: builtins.str,
     value: builtins.str,
     id: typing.Optional[builtins.str] = None,
+    object_identifier: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ObjectParameterObjectIdentifier, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    object_type: typing.Optional[builtins.str] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
     count: typing.Optional[jsii.Number] = None,
     depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
@@ -742,10 +752,10 @@ def _typecheckingstub__906ae18b9abdb83183952dd9a60617f77316eef8e0b0745cde6f3915e
     provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
     provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     key: builtins.str,
-    object_identifier: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ObjectParameterObjectIdentifier, typing.Dict[builtins.str, typing.Any]]]],
-    object_type: builtins.str,
     value: builtins.str,
     id: typing.Optional[builtins.str] = None,
+    object_identifier: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ObjectParameterObjectIdentifier, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    object_type: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
