@@ -34,7 +34,8 @@ class ProcedureGrant(
         id_: builtins.str,
         *,
         database_name: builtins.str,
-        schema_name: builtins.str,
+        roles: typing.Sequence[builtins.str],
+        argument_data_types: typing.Optional[typing.Sequence[builtins.str]] = None,
         arguments: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["ProcedureGrantArguments", typing.Dict[builtins.str, typing.Any]]]]] = None,
         enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
@@ -42,7 +43,7 @@ class ProcedureGrant(
         privilege: typing.Optional[builtins.str] = None,
         procedure_name: typing.Optional[builtins.str] = None,
         return_type: typing.Optional[builtins.str] = None,
-        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         shares: typing.Optional[typing.Sequence[builtins.str]] = None,
         with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -58,7 +59,8 @@ class ProcedureGrant(
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param database_name: The name of the database containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#database_name ProcedureGrant#database_name}
-        :param schema_name: The name of the schema containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
+        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
+        :param argument_data_types: List of the argument data types for the procedure (must be present if procedure has arguments and procedure_name is present). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#argument_data_types ProcedureGrant#argument_data_types}
         :param arguments: arguments block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#arguments ProcedureGrant#arguments}
         :param enable_multiple_grants: When this is set to true, multiple grants of the same type can be created. This will cause Terraform to not revoke grants applied to roles and objects outside Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#enable_multiple_grants ProcedureGrant#enable_multiple_grants}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#id ProcedureGrant#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -66,7 +68,7 @@ class ProcedureGrant(
         :param privilege: The privilege to grant on the current or future procedure. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#privilege ProcedureGrant#privilege}
         :param procedure_name: The name of the procedure on which to grant privileges immediately (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#procedure_name ProcedureGrant#procedure_name}
         :param return_type: The return type of the procedure (must be present if procedure_name is present). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#return_type ProcedureGrant#return_type}
-        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
+        :param schema_name: The name of the schema containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
         :param shares: Grants privilege to these shares (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#shares ProcedureGrant#shares}
         :param with_grant_option: When this is set to true, allows the recipient role to grant the privileges to other roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#with_grant_option ProcedureGrant#with_grant_option}
         :param connection: 
@@ -83,7 +85,8 @@ class ProcedureGrant(
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ProcedureGrantConfig(
             database_name=database_name,
-            schema_name=schema_name,
+            roles=roles,
+            argument_data_types=argument_data_types,
             arguments=arguments,
             enable_multiple_grants=enable_multiple_grants,
             id=id,
@@ -91,7 +94,7 @@ class ProcedureGrant(
             privilege=privilege,
             procedure_name=procedure_name,
             return_type=return_type,
-            roles=roles,
+            schema_name=schema_name,
             shares=shares,
             with_grant_option=with_grant_option,
             connection=connection,
@@ -118,6 +121,10 @@ class ProcedureGrant(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putArguments", [value]))
 
+    @jsii.member(jsii_name="resetArgumentDataTypes")
+    def reset_argument_data_types(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetArgumentDataTypes", []))
+
     @jsii.member(jsii_name="resetArguments")
     def reset_arguments(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetArguments", []))
@@ -146,9 +153,9 @@ class ProcedureGrant(
     def reset_return_type(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetReturnType", []))
 
-    @jsii.member(jsii_name="resetRoles")
-    def reset_roles(self) -> None:
-        return typing.cast(None, jsii.invoke(self, "resetRoles", []))
+    @jsii.member(jsii_name="resetSchemaName")
+    def reset_schema_name(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetSchemaName", []))
 
     @jsii.member(jsii_name="resetShares")
     def reset_shares(self) -> None:
@@ -172,6 +179,11 @@ class ProcedureGrant(
     def arguments(self) -> "ProcedureGrantArgumentsList":
         return typing.cast("ProcedureGrantArgumentsList", jsii.get(self, "arguments"))
 
+    @builtins.property
+    @jsii.member(jsii_name="argumentDataTypesInput")
+    def argument_data_types_input(self) -> typing.Optional[typing.List[builtins.str]]:
+        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "argumentDataTypesInput"))
+
     @builtins.property
     @jsii.member(jsii_name="argumentsInput")
     def arguments_input(
@@ -240,6 +252,18 @@ class ProcedureGrant(
     ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "withGrantOptionInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="argumentDataTypes")
+    def argument_data_types(self) -> typing.List[builtins.str]:
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "argumentDataTypes"))
+
+    @argument_data_types.setter
+    def argument_data_types(self, value: typing.List[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__477872943ea6b32946bb10b04970130d696b742bd05b28673a9f70681b865208)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "argumentDataTypes", value)
+
     @builtins.property
     @jsii.member(jsii_name="databaseName")
     def database_name(self) -> builtins.str:
@@ -618,7 +642,8 @@ class ProcedureGrantArgumentsOutputReference(
         "provider": "provider",
         "provisioners": "provisioners",
         "database_name": "databaseName",
-        "schema_name": "schemaName",
+        "roles": "roles",
+        "argument_data_types": "argumentDataTypes",
         "arguments": "arguments",
         "enable_multiple_grants": "enableMultipleGrants",
         "id": "id",
@@ -626,7 +651,7 @@ class ProcedureGrantArgumentsOutputReference(
         "privilege": "privilege",
         "procedure_name": "procedureName",
         "return_type": "returnType",
-        "roles": "roles",
+        "schema_name": "schemaName",
         "shares": "shares",
         "with_grant_option": "withGrantOption",
     },
@@ -643,7 +668,8 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         database_name: builtins.str,
-        schema_name: builtins.str,
+        roles: typing.Sequence[builtins.str],
+        argument_data_types: typing.Optional[typing.Sequence[builtins.str]] = None,
         arguments: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ProcedureGrantArguments, typing.Dict[builtins.str, typing.Any]]]]] = None,
         enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
@@ -651,7 +677,7 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         privilege: typing.Optional[builtins.str] = None,
         procedure_name: typing.Optional[builtins.str] = None,
         return_type: typing.Optional[builtins.str] = None,
-        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         shares: typing.Optional[typing.Sequence[builtins.str]] = None,
         with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
@@ -664,7 +690,8 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param provider: 
         :param provisioners: 
         :param database_name: The name of the database containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#database_name ProcedureGrant#database_name}
-        :param schema_name: The name of the schema containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
+        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
+        :param argument_data_types: List of the argument data types for the procedure (must be present if procedure has arguments and procedure_name is present). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#argument_data_types ProcedureGrant#argument_data_types}
         :param arguments: arguments block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#arguments ProcedureGrant#arguments}
         :param enable_multiple_grants: When this is set to true, multiple grants of the same type can be created. This will cause Terraform to not revoke grants applied to roles and objects outside Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#enable_multiple_grants ProcedureGrant#enable_multiple_grants}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#id ProcedureGrant#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -672,7 +699,7 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param privilege: The privilege to grant on the current or future procedure. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#privilege ProcedureGrant#privilege}
         :param procedure_name: The name of the procedure on which to grant privileges immediately (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#procedure_name ProcedureGrant#procedure_name}
         :param return_type: The return type of the procedure (must be present if procedure_name is present). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#return_type ProcedureGrant#return_type}
-        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
+        :param schema_name: The name of the schema containing the current or future procedures on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
         :param shares: Grants privilege to these shares (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#shares ProcedureGrant#shares}
         :param with_grant_option: When this is set to true, allows the recipient role to grant the privileges to other roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#with_grant_option ProcedureGrant#with_grant_option}
         '''
@@ -688,7 +715,8 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
-            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
+            check_type(argname="argument roles", value=roles, expected_type=type_hints["roles"])
+            check_type(argname="argument argument_data_types", value=argument_data_types, expected_type=type_hints["argument_data_types"])
             check_type(argname="argument arguments", value=arguments, expected_type=type_hints["arguments"])
             check_type(argname="argument enable_multiple_grants", value=enable_multiple_grants, expected_type=type_hints["enable_multiple_grants"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
@@ -696,12 +724,12 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument privilege", value=privilege, expected_type=type_hints["privilege"])
             check_type(argname="argument procedure_name", value=procedure_name, expected_type=type_hints["procedure_name"])
             check_type(argname="argument return_type", value=return_type, expected_type=type_hints["return_type"])
-            check_type(argname="argument roles", value=roles, expected_type=type_hints["roles"])
+            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
             check_type(argname="argument shares", value=shares, expected_type=type_hints["shares"])
             check_type(argname="argument with_grant_option", value=with_grant_option, expected_type=type_hints["with_grant_option"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "database_name": database_name,
-            "schema_name": schema_name,
+            "roles": roles,
         }
         if connection is not None:
             self._values["connection"] = connection
@@ -717,6 +745,8 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["provider"] = provider
         if provisioners is not None:
             self._values["provisioners"] = provisioners
+        if argument_data_types is not None:
+            self._values["argument_data_types"] = argument_data_types
         if arguments is not None:
             self._values["arguments"] = arguments
         if enable_multiple_grants is not None:
@@ -731,8 +761,8 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["procedure_name"] = procedure_name
         if return_type is not None:
             self._values["return_type"] = return_type
-        if roles is not None:
-            self._values["roles"] = roles
+        if schema_name is not None:
+            self._values["schema_name"] = schema_name
         if shares is not None:
             self._values["shares"] = shares
         if with_grant_option is not None:
@@ -811,14 +841,23 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def schema_name(self) -> builtins.str:
-        '''The name of the schema containing the current or future procedures on which to grant privileges.
+    def roles(self) -> typing.List[builtins.str]:
+        '''Grants privilege to these roles.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
         '''
-        result = self._values.get("schema_name")
-        assert result is not None, "Required property 'schema_name' is missing"
-        return typing.cast(builtins.str, result)
+        result = self._values.get("roles")
+        assert result is not None, "Required property 'roles' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
+    @builtins.property
+    def argument_data_types(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''List of the argument data types for the procedure (must be present if procedure has arguments and procedure_name is present).
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#argument_data_types ProcedureGrant#argument_data_types}
+        '''
+        result = self._values.get("argument_data_types")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
     def arguments(
@@ -895,13 +934,13 @@ class ProcedureGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def roles(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''Grants privilege to these roles.
+    def schema_name(self) -> typing.Optional[builtins.str]:
+        '''The name of the schema containing the current or future procedures on which to grant privileges.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#roles ProcedureGrant#roles}
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/procedure_grant#schema_name ProcedureGrant#schema_name}
         '''
-        result = self._values.get("roles")
-        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+        result = self._values.get("schema_name")
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def shares(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -950,7 +989,8 @@ def _typecheckingstub__eea9fb09d8b1ff9dc8b0801d6c5a7ecce837ed2b4bb6040d4a7a76378
     id_: builtins.str,
     *,
     database_name: builtins.str,
-    schema_name: builtins.str,
+    roles: typing.Sequence[builtins.str],
+    argument_data_types: typing.Optional[typing.Sequence[builtins.str]] = None,
     arguments: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ProcedureGrantArguments, typing.Dict[builtins.str, typing.Any]]]]] = None,
     enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     id: typing.Optional[builtins.str] = None,
@@ -958,7 +998,7 @@ def _typecheckingstub__eea9fb09d8b1ff9dc8b0801d6c5a7ecce837ed2b4bb6040d4a7a76378
     privilege: typing.Optional[builtins.str] = None,
     procedure_name: typing.Optional[builtins.str] = None,
     return_type: typing.Optional[builtins.str] = None,
-    roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    schema_name: typing.Optional[builtins.str] = None,
     shares: typing.Optional[typing.Sequence[builtins.str]] = None,
     with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -978,6 +1018,12 @@ def _typecheckingstub__3f65f126d184a547886788accfa6c605bdfbcb3d8309af396fb10dbb7
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__477872943ea6b32946bb10b04970130d696b742bd05b28673a9f70681b865208(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__b23216d64b34c19775f37d6cfe40d33ef813ee65dc3b63f6f516e07e07c29e91(
     value: builtins.str,
 ) -> None:
@@ -1127,7 +1173,8 @@ def _typecheckingstub__52f975c538217df3f4b6a74404d122fb0d457a1b28e6320f05c9a8228
     provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
     provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     database_name: builtins.str,
-    schema_name: builtins.str,
+    roles: typing.Sequence[builtins.str],
+    argument_data_types: typing.Optional[typing.Sequence[builtins.str]] = None,
     arguments: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[ProcedureGrantArguments, typing.Dict[builtins.str, typing.Any]]]]] = None,
     enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     id: typing.Optional[builtins.str] = None,
@@ -1135,7 +1182,7 @@ def _typecheckingstub__52f975c538217df3f4b6a74404d122fb0d457a1b28e6320f05c9a8228
     privilege: typing.Optional[builtins.str] = None,
     procedure_name: typing.Optional[builtins.str] = None,
     return_type: typing.Optional[builtins.str] = None,
-    roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    schema_name: typing.Optional[builtins.str] = None,
     shares: typing.Optional[typing.Sequence[builtins.str]] = None,
     with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
 ) -> None:
