@@ -34,12 +34,12 @@ class TaskGrant(
         id_: builtins.str,
         *,
         database_name: builtins.str,
-        schema_name: builtins.str,
+        roles: typing.Sequence[builtins.str],
         enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         on_future: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         privilege: typing.Optional[builtins.str] = None,
-        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         task_name: typing.Optional[builtins.str] = None,
         with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -55,12 +55,12 @@ class TaskGrant(
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param database_name: The name of the database containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#database_name TaskGrant#database_name}
-        :param schema_name: The name of the schema containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
+        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
         :param enable_multiple_grants: When this is set to true, multiple grants of the same type can be created. This will cause Terraform to not revoke grants applied to roles and objects outside Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#enable_multiple_grants TaskGrant#enable_multiple_grants}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#id TaskGrant#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param on_future: When this is set to true and a schema_name is provided, apply this grant on all future tasks in the given schema. When this is true and no schema_name is provided apply this grant on all future tasks in the given database. The task_name field must be unset in order to use on_future. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#on_future TaskGrant#on_future}
         :param privilege: The privilege to grant on the current or future task. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#privilege TaskGrant#privilege}
-        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
+        :param schema_name: The name of the schema containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
         :param task_name: The name of the task on which to grant privileges immediately (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#task_name TaskGrant#task_name}
         :param with_grant_option: When this is set to true, allows the recipient role to grant the privileges to other roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#with_grant_option TaskGrant#with_grant_option}
         :param connection: 
@@ -77,12 +77,12 @@ class TaskGrant(
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = TaskGrantConfig(
             database_name=database_name,
-            schema_name=schema_name,
+            roles=roles,
             enable_multiple_grants=enable_multiple_grants,
             id=id,
             on_future=on_future,
             privilege=privilege,
-            roles=roles,
+            schema_name=schema_name,
             task_name=task_name,
             with_grant_option=with_grant_option,
             connection=connection,
@@ -112,9 +112,9 @@ class TaskGrant(
     def reset_privilege(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetPrivilege", []))
 
-    @jsii.member(jsii_name="resetRoles")
-    def reset_roles(self) -> None:
-        return typing.cast(None, jsii.invoke(self, "resetRoles", []))
+    @jsii.member(jsii_name="resetSchemaName")
+    def reset_schema_name(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetSchemaName", []))
 
     @jsii.member(jsii_name="resetTaskName")
     def reset_task_name(self) -> None:
@@ -318,12 +318,12 @@ class TaskGrant(
         "provider": "provider",
         "provisioners": "provisioners",
         "database_name": "databaseName",
-        "schema_name": "schemaName",
+        "roles": "roles",
         "enable_multiple_grants": "enableMultipleGrants",
         "id": "id",
         "on_future": "onFuture",
         "privilege": "privilege",
-        "roles": "roles",
+        "schema_name": "schemaName",
         "task_name": "taskName",
         "with_grant_option": "withGrantOption",
     },
@@ -340,12 +340,12 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         database_name: builtins.str,
-        schema_name: builtins.str,
+        roles: typing.Sequence[builtins.str],
         enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         on_future: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         privilege: typing.Optional[builtins.str] = None,
-        roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         task_name: typing.Optional[builtins.str] = None,
         with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
@@ -358,12 +358,12 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param provider: 
         :param provisioners: 
         :param database_name: The name of the database containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#database_name TaskGrant#database_name}
-        :param schema_name: The name of the schema containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
+        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
         :param enable_multiple_grants: When this is set to true, multiple grants of the same type can be created. This will cause Terraform to not revoke grants applied to roles and objects outside Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#enable_multiple_grants TaskGrant#enable_multiple_grants}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#id TaskGrant#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param on_future: When this is set to true and a schema_name is provided, apply this grant on all future tasks in the given schema. When this is true and no schema_name is provided apply this grant on all future tasks in the given database. The task_name field must be unset in order to use on_future. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#on_future TaskGrant#on_future}
         :param privilege: The privilege to grant on the current or future task. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#privilege TaskGrant#privilege}
-        :param roles: Grants privilege to these roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
+        :param schema_name: The name of the schema containing the current or future tasks on which to grant privileges. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
         :param task_name: The name of the task on which to grant privileges immediately (only valid if on_future is false). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#task_name TaskGrant#task_name}
         :param with_grant_option: When this is set to true, allows the recipient role to grant the privileges to other roles. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#with_grant_option TaskGrant#with_grant_option}
         '''
@@ -379,17 +379,17 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument database_name", value=database_name, expected_type=type_hints["database_name"])
-            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
+            check_type(argname="argument roles", value=roles, expected_type=type_hints["roles"])
             check_type(argname="argument enable_multiple_grants", value=enable_multiple_grants, expected_type=type_hints["enable_multiple_grants"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument on_future", value=on_future, expected_type=type_hints["on_future"])
             check_type(argname="argument privilege", value=privilege, expected_type=type_hints["privilege"])
-            check_type(argname="argument roles", value=roles, expected_type=type_hints["roles"])
+            check_type(argname="argument schema_name", value=schema_name, expected_type=type_hints["schema_name"])
             check_type(argname="argument task_name", value=task_name, expected_type=type_hints["task_name"])
             check_type(argname="argument with_grant_option", value=with_grant_option, expected_type=type_hints["with_grant_option"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "database_name": database_name,
-            "schema_name": schema_name,
+            "roles": roles,
         }
         if connection is not None:
             self._values["connection"] = connection
@@ -413,8 +413,8 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["on_future"] = on_future
         if privilege is not None:
             self._values["privilege"] = privilege
-        if roles is not None:
-            self._values["roles"] = roles
+        if schema_name is not None:
+            self._values["schema_name"] = schema_name
         if task_name is not None:
             self._values["task_name"] = task_name
         if with_grant_option is not None:
@@ -493,14 +493,14 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def schema_name(self) -> builtins.str:
-        '''The name of the schema containing the current or future tasks on which to grant privileges.
+    def roles(self) -> typing.List[builtins.str]:
+        '''Grants privilege to these roles.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
         '''
-        result = self._values.get("schema_name")
-        assert result is not None, "Required property 'schema_name' is missing"
-        return typing.cast(builtins.str, result)
+        result = self._values.get("roles")
+        assert result is not None, "Required property 'roles' is missing"
+        return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
     def enable_multiple_grants(
@@ -548,13 +548,13 @@ class TaskGrantConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def roles(self) -> typing.Optional[typing.List[builtins.str]]:
-        '''Grants privilege to these roles.
+    def schema_name(self) -> typing.Optional[builtins.str]:
+        '''The name of the schema containing the current or future tasks on which to grant privileges.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#roles TaskGrant#roles}
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/snowflake/r/task_grant#schema_name TaskGrant#schema_name}
         '''
-        result = self._values.get("roles")
-        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+        result = self._values.get("schema_name")
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def task_name(self) -> typing.Optional[builtins.str]:
@@ -600,12 +600,12 @@ def _typecheckingstub__45a4e09618276607dff2a10927db7cee73e96596a633112548155ab11
     id_: builtins.str,
     *,
     database_name: builtins.str,
-    schema_name: builtins.str,
+    roles: typing.Sequence[builtins.str],
     enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     id: typing.Optional[builtins.str] = None,
     on_future: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     privilege: typing.Optional[builtins.str] = None,
-    roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    schema_name: typing.Optional[builtins.str] = None,
     task_name: typing.Optional[builtins.str] = None,
     with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -683,12 +683,12 @@ def _typecheckingstub__85b941d506f0d436c2d2546dd8c7852ef55cb86f18c053a9c55ed1a26
     provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
     provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     database_name: builtins.str,
-    schema_name: builtins.str,
+    roles: typing.Sequence[builtins.str],
     enable_multiple_grants: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     id: typing.Optional[builtins.str] = None,
     on_future: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     privilege: typing.Optional[builtins.str] = None,
-    roles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    schema_name: typing.Optional[builtins.str] = None,
     task_name: typing.Optional[builtins.str] = None,
     with_grant_option: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
 ) -> None:
